@@ -1,10 +1,10 @@
-run_clustermq <- function(config){
+run_clustermq <- function(config) {
   assert_pkg("clustermq", version = "0.8.5")
   config$queue <- new_priority_queue(
     config = config,
     jobs = config$jobs_imports
   )
-  if (!config$queue$empty()){
+  if (!config$queue$empty()) {
     config$workers <- clustermq::workers(
       n_jobs = config$jobs,
       template = config$template
@@ -16,9 +16,9 @@ run_clustermq <- function(config){
   }
 }
 
-cmq_set_common_data <- function(config){
+cmq_set_common_data <- function(config) {
   export <- list()
-  if (identical(config$envir, globalenv())){
+  if (identical(config$envir, globalenv())) {
     export <- as.list(config$envir, all.names = TRUE) # nocov
   }
   config$cache$flush_cache()
@@ -33,35 +33,35 @@ cmq_set_common_data <- function(config){
   )
 }
 
-cmq_master <- function(config){
+cmq_master <- function(config) {
   on.exit(config$workers$finalize())
-  while (config$counter$remaining > 0){
+  while (config$counter$remaining > 0) {
     msg <- config$workers$receive_data()
     cmq_conclude_build(msg = msg, config = config)
-    if (!identical(msg$token, "set_common_data_token")){
+    if (!identical(msg$token, "set_common_data_token")) {
       config$workers$send_common_data()
-    } else if (!config$queue$empty()){
+    } else if (!config$queue$empty()) {
       cmq_send_target(config)
     } else {
       config$workers$send_shutdown_worker()
     }
   }
-  if (config$workers$cleanup()){
+  if (config$workers$cleanup()) {
     on.exit()
   }
 }
 
-cmq_send_target <- function(config){
+cmq_send_target <- function(config) {
   target <- config$queue$pop0()
   # Longer tests will catch this:
-  if (!length(target)){
+  if (!length(target)) {
     config$workers$send_wait() # nocov
     return() # nocov
   }
   meta <- drake_meta(target = target, config = config)
   # Target should not even be in the priority queue
   # nocov start
-  if (!should_build_target(target = target, meta = meta, config = config)){
+  if (!should_build_target(target = target, meta = meta, config = config)) {
     console_skip(target = target, config = config)
     cmq_conclude_target(target = target, config = config)
     config$workers$send_wait()
@@ -70,8 +70,8 @@ cmq_send_target <- function(config){
   # nocov end
   meta$start <- proc.time()
   announce_build(target = target, meta = meta, config = config)
-  if (identical(config$caching, "master")){
-    prune_envir(targets = target, config = config, jobs = 1)
+  if (identical(config$caching, "master")) {
+    manage_memory(targets = target, config = config, jobs = 1)
     deps <- cmq_deps_list(target = target, config = config)
   } else {
     deps <- NULL
@@ -87,16 +87,17 @@ cmq_send_target <- function(config){
   )
 }
 
-cmq_deps_list <- function(target, config){
-  deps <- dependencies(targets = target, config = config) %>%
-    intersect(config$plan$target)
-  lapply(
+cmq_deps_list <- function(target, config) {
+  deps <- dependencies(targets = target, config = config)
+  deps <- intersect(deps, config$plan$target)
+  out <- lapply(
     X = deps,
-    FUN = function(name){
+    FUN = function(name) {
       config$envir[[name]]
     }
-  ) %>%
-    setNames(deps)
+  )
+  names(out) <- deps
+  out
 }
 
 #' @title Build a target using the clustermq backend
@@ -108,20 +109,20 @@ cmq_deps_list <- function(target, config){
 #' @param meta list of metadata
 #' @param deps named list of target dependencies
 #' @param config a [drake_config()] list
-cmq_build <- function(target, meta, deps, config){
-  if (identical(config$garbage_collection, TRUE)){
+cmq_build <- function(target, meta, deps, config) {
+  if (identical(config$garbage_collection, TRUE)) {
     gc()
   }
   do_prework(config = config, verbose_packages = FALSE)
-  if (identical(config$caching, "master")){
-    for (dep in names(deps)){
+  if (identical(config$caching, "master")) {
+    for (dep in names(deps)) {
       config$envir[[dep]] <- deps[[dep]]
     }
   } else {
-    prune_envir(targets = target, config = config, jobs = 1)
+    manage_memory(targets = target, config = config, jobs = 1)
   }
   build <- just_build(target = target, meta = meta, config = config)
-  if (identical(config$caching, "master")){
+  if (identical(config$caching, "master")) {
     build$checksum <- mc_get_outfile_checksum(target, config)
     return(build)
   }
@@ -135,16 +136,16 @@ cmq_build <- function(target, meta, deps, config){
   list(target = target, checksum = mc_get_checksum(target, config))
 }
 
-cmq_conclude_build <- function(msg, config){
+cmq_conclude_build <- function(msg, config) {
   build <- msg$result
-  if (is.null(build)){
+  if (is.null(build)) {
     return()
   }
-  if (inherits(build, "try-error")){
+  if (inherits(build, "try-error")) {
     stop(attr(build, "condition")$message, call. = FALSE) # nocov
   }
   cmq_conclude_target(target = build$target, config = config)
-  if (identical(config$caching, "worker")){
+  if (identical(config$caching, "worker")) {
     mc_wait_checksum(
       target = build$target,
       checksum = build$checksum,
@@ -166,13 +167,7 @@ cmq_conclude_build <- function(msg, config){
   )
 }
 
-cmq_conclude_target <- function(target, config){
-  revdeps <- dependencies(
-    targets = target,
-    config = config,
-    reverse = TRUE
-  ) %>%
-    intersect(y = config$queue$list())
-  config$queue$decrease_key(targets = revdeps)
+cmq_conclude_target <- function(target, config) {
+  decrease_revdep_keys(queue = config$queue, target = target, config = config)
   config$counter$remaining <- config$counter$remaining - 1
 }
