@@ -8,12 +8,12 @@ console <- function(imported, target, config) {
   }
 }
 
-console_generic <- function(target, config, cutoff = 1, pattern = "target"){
-  if (config$verbose < cutoff){
+console_generic <- function(target, config, cutoff = 1, pattern = "target") {
+  if (config$verbose < cutoff) {
     return()
   }
   text <- target
-  if (is_file(target)){
+  if (is_file(target)) {
     text <- paste0("file ", text)
   }
   text <- paste(pattern, text)
@@ -21,39 +21,39 @@ console_generic <- function(target, config, cutoff = 1, pattern = "target"){
 
 }
 
-console_missing <- function(target, config){
+console_missing <- function(target, config) {
   console_generic(target, config, 3, "missing")
 }
 
-console_import <- function(target, config){
+console_import <- function(target, config) {
   console_generic(target, config, 4, "import")
 }
 
-console_skip <- function(target, config){
+console_skip <- function(target, config) {
   console_generic(target, config, 4, "skip")
 }
 
-console_store <- function(target, config){
+console_store <- function(target, config) {
   console_generic(target, config, 4, "store")
 }
 
-console_target <- function(target, config){
+console_target <- function(target, config) {
   console_generic(target, config, 1, "target")
 }
 
-console_cache <- function(config){
-  if (config$verbose < 2){
+console_cache <- function(config) {
+  if (config$verbose < 2) {
     return()
   }
-  if (is.null(config$cache_path)){
+  if (is.null(config$cache_path)) {
     config$cache_path <- default_cache_path()
   }
-  paste("cache", config$cache_path) %>%
-    finish_console(pattern = "cache", config = config)
+  out <- paste("cache", config$cache_path)
+  finish_console(out, pattern = "cache", config = config)
 }
 
-console_preprocess <- function(text, config){
-  if (!length(config$verbose) || config$verbose < 2){
+console_preprocess <- function(text, config) {
+  if (!length(config$verbose) || config$verbose < 2) {
     return()
   }
   finish_console(
@@ -65,85 +65,85 @@ console_preprocess <- function(text, config){
 
 console_many_targets <- function(
   targets, pattern, config, color = color_of(pattern), type = "item"
-){
-  if (config$verbose < 2){
+) {
+  if (config$verbose < 2) {
     return()
   }
   n <- length(targets)
-  if (n < 1){
+  if (n < 1) {
     return(invisible())
   }
   targets[is_file(targets)] <- paste("file", targets[is_file(targets)])
-  paste0(
+  out <- paste0(
     pattern,
     " ", n, " ", type,
     ifelse(n == 1, "", "s"),
     ": ",
     paste(targets, collapse = ", ")
-  ) %>%
-    finish_console(pattern = pattern, config = config)
+  )
+  finish_console(out, pattern = pattern, config = config)
 }
 
-console_parLapply <- function(config){ # nolint
+console_parLapply <- function(config) { # nolint
   text <- paste("load parallel socket cluster with", config$jobs, "workers")
   finish_console(text = text, pattern = "load", config = config)
 }
 
-console_retry <- function(target, error, retries, config){
-  if (retries <= config$retries){
+console_retry <- function(target, error, retries, config) {
+  if (retries <= config$retries) {
     text <- paste0("retry ", target, ": ", retries, " of ", config$retries)
     finish_console(text = text, pattern = "retry", config = config)
   }
 }
 
-console_up_to_date <- function(config){
-  if (!config$verbose){
+console_up_to_date <- function(config) {
+  if (!config$verbose) {
     return(invisible())
   }
   any_attempted <- get_attempt_flag(config = config)
   custom_triggers <- "trigger" %in% colnames(plan) ||
     !identical(config$trigger, trigger())
-  if (!any_attempted && !custom_triggers && !config$skip_imports){
+  if (!any_attempted && !custom_triggers && !config$skip_imports) {
     console_all_up_to_date(config = config)
     return(invisible())
   }
-  if (config$skip_imports){
+  if (config$skip_imports) {
     console_skipped_imports(config = config)
   }
-  if (custom_triggers){
+  if (custom_triggers) {
     console_custom_triggers(config)
   }
 }
 
-console_all_up_to_date <- function(config){
-  color("All targets are already up to date.", colors["target"]) %>%
-    drake_message(config = config)
+console_all_up_to_date <- function(config) {
+  out <- color("All targets are already up to date.", colors["target"])
+  drake_message(out, config = config)
 }
 
-console_skipped_imports <- function(config){
-  color(
+console_skipped_imports <- function(config) {
+  out <- color(
     paste(
       "Skipped the imports.",
       "If some imports are not already cached, targets could be out of date."
     ),
     colors["trigger"]
-  ) %>%
-    drake_message(config = config)
+  )
+  drake_message(out, config = config)
 }
 
-console_custom_triggers <- function(config){
-  color(
+console_custom_triggers <- function(config) {
+  out <- color(
     paste(
       "Used non-default triggers.",
       "Some targets may not be up to date."
     ),
     colors["trigger"]
-  ) %>%
-    drake_message(config = config)
+  )
+  drake_message(out, config = config)
 }
 
-console_persistent_workers <- function(config){
-  if (config$verbose < 2){
+console_persistent_workers <- function(config) {
+  if (config$verbose < 2) {
     return()
   }
   finish_console(
@@ -153,64 +153,59 @@ console_persistent_workers <- function(config){
   )
 }
 
-finish_console <- function(text, pattern, config){
-  if (is.null(config$verbose) || config$verbose < 1){
+finish_console <- function(text, pattern, config) {
+  if (is.null(config$verbose) || config$verbose < 1) {
     return(invisible())
   }
-  msg <- crop_text(x = text) %>%
-   color_grep(pattern = pattern, color = color_of(pattern))
+  msg <- crop_text(x = text)
+  msg <- color_grep(msg, pattern = pattern, color = color_of(pattern))
   drake_message(msg, config = config)
 }
 
-drake_message <- function(..., config){
-  text <- paste0(...)
-  if (requireNamespace("crayon", quietly = TRUE)){
+drake_log <- function(..., prefix, config) {
+  text <- paste0(prefix, ...)
+  if (requireNamespace("crayon", quietly = TRUE)) {
     text <- crayon::strip_style(text)
   }
-  if (!is.null(config$console_log_file)){
+  if (!is.null(config$console_log_file)) {
     write(
       x = text,
       file = config$console_log_file,
       append = TRUE
     )
   }
+  invisible()
+}
+
+drake_log_message <- function(..., config) {
+  drake_log(..., prefix = "", config = config)
+}
+
+drake_log_warning <- function(..., config) {
+  drake_log(..., prefix = "Warning: ", config = config)
+}
+
+drake_log_error <- function(..., config) {
+  drake_log(..., prefix = "Error: ", config = config)
+}
+
+drake_message <- function(..., config) {
+  drake_log_message(..., config = config)
   message(..., sep = "")
 }
 
-drake_warning <- function(..., config){
-  text <- paste0("Warning: ", ...)
-  if (requireNamespace("crayon", quietly = TRUE)){
-    text <- crayon::strip_style(text)
-  }
-  if (!is.null(config$console_log_file)){
-    write(
-      x = text,
-      sep = "",
-      file = config$console_log_file,
-      append = TRUE
-    )
-  }
+drake_warning <- function(..., config) {
+  drake_log_warning(..., config = config)
   warning(..., call. = FALSE)
 }
 
-drake_error <- function(..., config){
-  text <- paste0("Error: ", ...)
-  if (requireNamespace("crayon", quietly = TRUE)){
-    text <- crayon::strip_style(text)
-  }
-  if (!is.null(config$console_log_file)){
-    write(
-      x = text,
-      sep = "",
-      file = config$console_log_file,
-      append = TRUE
-    )
-  }
+drake_error <- function(..., config) {
+  drake_log_error(..., config = config)
   stop(..., call. = FALSE)
 }
 
 crop_text <- Vectorize(function(x, width = getOption("width")) {
-  if (nchar(x) > width){
+  if (nchar(x) > width) {
     x <- paste0(substr(x, 1, width - 3), "...")
   }
   x
@@ -218,7 +213,7 @@ crop_text <- Vectorize(function(x, width = getOption("width")) {
 "x", USE.NAMES = FALSE)
 
 crop_lines <- function(x, n = 10) {
-  if (length(x) > n){
+  if (length(x) > n) {
     x <- x[1:(n - 1)]
     x[n] <- "..."
   }
@@ -227,10 +222,11 @@ crop_lines <- function(x, n = 10) {
 
 multiline_message <- function(x) {
   n <- 30
-  if (length(x) > n){
+  if (length(x) > n) {
     x <- c(x[1:(n - 1)], "...")
   }
-  paste0("  ", x) %>% paste(collapse = "\n")
+  x <- paste0("  ", x)
+  paste(x, collapse = "\n")
 }
 
 #' @title Default verbosity for `drake`
@@ -238,9 +234,9 @@ multiline_message <- function(x) {
 #'   `pkgconfig::set_config("drake::verbose" = 2)`.
 #' @export
 #' @keywords internal
-#' @return a logical or integer with the value of
+#' @return A logical or integer with the value of
 #'   the default `verbose` argument to `drake` functions.
-default_verbose <- function(){
+default_verbose <- function() {
   default <- pkgconfig::get_config("drake::verbose")
   ifelse(!length(default), 1, default)
 }
@@ -256,19 +252,19 @@ default_verbose <- function(){
 #'   `target` as a symbol (`FALSE`) or character vector
 #'   (`TRUE`).
 #' @examples
-#' plan <- drake_plan(x = rnorm(15))
+#' plan <- drake_plan(x = sample.int(15))
 #' cache <- storr::storr_environment() # custom in-memory cache
 #' make(plan, cache = cache)
 #' config <- drake_config(plan, cache = cache)
 #' show_source(x, config)
-show_source <- function(target, config, character_only = FALSE){
-  if (!character_only){
+show_source <- function(target, config, character_only = FALSE) {
+  if (!character_only) {
     target <- as.character(substitute(target))
   }
   cache <- config$cache
   meta <- diagnose(target = target, cache = cache, character_only = TRUE)
   prefix <- ifelse(is_file(target), "File ", "Target ")
-  if (meta$imported){
+  if (meta$imported) {
     message(prefix, target, " was imported.")
   } else {
     command <- gsub("^\\{\n ", "", meta$command)
