@@ -16,8 +16,8 @@
 #' prepare_distributed(config = config)
 #' })
 #' }
-prepare_distributed <- function(config){
-  if (!file.exists(config$cache_path)){
+prepare_distributed <- function(config) {
+  if (!file.exists(config$cache_path)) {
     dir.create(config$cache_path)
   }
   writeLines(
@@ -31,35 +31,36 @@ prepare_distributed <- function(config){
     envir = globalenv(),
     file = globalenv_file(config$cache_path)
   )
-  for (item in c("envir", "schedule")){
+  for (item in c("envir", "schedule")) {
     config$cache$set(key = item, value = config[[item]], namespace = "config")
   }
   invisible()
 }
 
-finish_distributed <- function(config){
+finish_distributed <- function(config) {
   dir <- cache_path(config$cache)
   file <- globalenv_file(dir)
   unlink(file, force = TRUE)
 }
 
-build_distributed <- function(target, cache_path, check = TRUE){
+build_distributed <- function(target, cache_path, check = TRUE) {
   config <- recover_drake_config(cache_path = cache_path)
   eval(parse(text = "base::require(drake, quietly = TRUE)"))
   do_prework(config = config, verbose_packages = FALSE)
-  if (check){
+  if (check) {
     check_build_store(target = target, config = config)
   } else {
-    prune_envir(targets = target, config = config)
+    manage_memory(targets = target, config = config)
     build_store(target = target, config = config)
   }
   invisible()
 }
 
-recover_drake_config <- function(cache_path){
-  fetch_cache <- tryCatch(
-    readLines(con = file.path(cache_path, fetch_cache_file)) %>%
-      paste0(collapse = "\n"),
+recover_drake_config <- function(cache_path) {
+  fetch_cache <- tryCatch({
+      out <- readLines(con = file.path(cache_path, fetch_cache_file))
+      paste0(out, collapse = "\n")
+    },
     error = error_null
   )
   cache <- this_cache(cache_path, verbose = FALSE, fetch_cache = fetch_cache)
