@@ -1,26 +1,27 @@
 default_testing_scenario <- "local_parLapply_1"
 test_option_name <- "drake_test_scenario"
 
-testing_scenarios <- function(){
+testing_scenarios <- function() {
   file <- file.path("testing", "scenarios.csv")
   path <- system.file(file, package = "drake", mustWork = TRUE)
   x <- read.csv(path, stringsAsFactors = FALSE)
-  rownames(x) <- paste(
+  rn <- paste(
     x$envir,
     x$parallelism,
     x$jobs,
     x$backend,
     x$caching,
     sep = "_"
-  ) %>%
-    gsub(pattern = "_*$", replacement = "")
+  )
+  rn <- gsub(pattern = "_*$", replacement = "", x = rn)
+  rownames(x) <- rn
   x$backend <- backend_code(x$backend)
   x$envir <- envir_code(x$envir)
   x$caching[!nzchar(x$caching)] <- "worker"
   apply_skip_os(x)
 }
 
-backend_code <- function(x){
+backend_code <- function(x) {
   ifelse(
     nzchar(x),
     paste0("future::plan(", x, ")"),
@@ -28,7 +29,7 @@ backend_code <- function(x){
   )
 }
 
-envir_code <- function(x){
+envir_code <- function(x) {
   ifelse(
     x == "local",
     "new.env(parent = globalenv())",
@@ -37,14 +38,14 @@ envir_code <- function(x){
 }
 
 # For the table of possible testing scenarios x.
-apply_skip_os <- function(x){
+apply_skip_os <- function(x) {
   x$skip_os <- ""
   skip_on_windows <- grepl("mclapply|clustermq", x$parallelism)
   x$skip_os[skip_on_windows] <- "windows"
   x
 }
 
-testing_scenario_names <- function(){
+testing_scenario_names <- function() {
   rownames(testing_scenarios())
 }
 
@@ -55,7 +56,7 @@ get_testing_scenario <- function() {
 
 get_testing_scenario_name <- function() {
   scenario <- getOption(test_option_name)
-  if (!length(scenario)){
+  if (!length(scenario)) {
     scenario <- match.arg(
       arg = default_testing_scenario,
       choices = testing_scenario_names()
@@ -71,7 +72,7 @@ set_testing_scenario <- function(scenario = NULL) {
   options(new)
 }
 
-should_skip <- function(scenario_name, os = this_os()){
+should_skip <- function(scenario_name, os = this_os()) {
   scenarios <- testing_scenarios()
   scenario_name <- match.arg(
     arg = scenario_name,
@@ -85,16 +86,16 @@ test_scenarios <- function(
   unit_test_dir = unit_test_files(),
   skip_criterion = should_skip,
   ...
-){
+) {
   assert_pkg("testthat")
   scenarios <- testing_scenarios()
-  for (index in seq_along(along.with = scenario_names)){
+  for (index in seq_along(along.with = scenario_names)) {
     scenario_names[index] <- match.arg(
       arg = scenario_names[index],
       choices = testing_scenario_names()
     )
   }
-  for (scenario_name in scenario_names){
+  for (scenario_name in scenario_names) {
     skip <- skip_criterion(scenario_name)
     msg <- ifelse(skip, "skip", "run")
     message(scenario_name, ": ", msg, sep = "")
