@@ -19,13 +19,13 @@
 #' # Now look in '.drake/ts' for dummy timestamp files.
 #' })
 #' }
-time_stamps <- function(config){
+time_stamps <- function(config) {
   cache_path <- config$cache_path
   stamp_dir <- time_stamp_dir(cache_path)
   dir_empty(stamp_dir)
   write_time_stamp_template(cache_path)
   build_these <- first_outdated(config = config)
-  if (length(build_these)){
+  if (length(build_these)) {
     set_attempt_flag(key = "_attempt", config = config)
   }
   stamp_these <- setdiff(config$plan$target, build_these)
@@ -34,7 +34,7 @@ time_stamps <- function(config){
   return(invisible())
 }
 
-safe_encode <- Vectorize(function(x, hash_algo){
+safe_encode <- Vectorize(function(x, hash_algo) {
   digest::digest(
     object = x,
     algo = hash_algo,
@@ -44,26 +44,26 @@ safe_encode <- Vectorize(function(x, hash_algo){
 },
 "x")
 
-time_stamp <- function(target, config){
-  if (!length(target)){
+time_stamp <- function(target, config) {
+  if (!length(target)) {
     return(character(0))
   }
   safe_encode(x = target, hash_algo = config$short_hash_algo)
 }
 
-time_stamp_file <- function(target, config){
+time_stamp_file <- function(target, config) {
   stamp <- time_stamp(target = target, config)
   dir <- time_stamp_dir(cache_path(config$cache))
   file.path(dir, stamp)
 }
 
-time_stamp_target <- function(target, config){
+time_stamp_target <- function(target, config) {
   stamp <- time_stamp(target = target, config)
   dir <- time_stamp_dir(cache_value_macro)
   file.path(dir, stamp)
 }
 
-write_time_stamp <- function(target, config){
+write_time_stamp <- function(target, config) {
   cache_path <- cache_path(config$cache)
   template <- time_stamp_template(cache_path)
   file.copy(
@@ -74,25 +74,25 @@ write_time_stamp <- function(target, config){
   )
 }
 
-time_stamp_dir <- function(cache_path){
+time_stamp_dir <- function(cache_path) {
   file.path(cache_path, "ts")
 }
 
-time_stamp_template <- function(cache_path){
+time_stamp_template <- function(cache_path) {
   file.path(cache_path, "timestamp")
 }
 
-dir_empty <- function(x){
+dir_empty <- function(x) {
   unlink(x, recursive = TRUE, force = TRUE)
-  fs::dir_create(x)
+  dir.create(x)
 }
 
-file_overwrite <- function(x){
+file_overwrite <- function(x) {
   unlink(x, force = TRUE)
   file.create(x)
 }
 
-write_time_stamp_template <- function(cache_path){
+write_time_stamp_template <- function(cache_path) {
   zip <- system.file(
     "timestamp.zip",
     package = "drake",
