@@ -43,7 +43,7 @@ test_with_dir("recipe commands", {
 test_with_dir("no Makefile for make_imports()", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   expect_equal(cached(), character(0))
-  f <- function(){
+  f <- function() {
     return(1)
   }
   x <- drake_plan(a = f())
@@ -158,30 +158,20 @@ test_with_dir("Makefile stuff in globalenv()", {
 test_with_dir("packages are loaded in prework", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   skip_if_not_installed("abind")
-  skip_if_not_installed("MASS")
 
   original <- getOption("test_drake_option_12345")
   options(test_drake_option_12345 = "unset")
   expect_equal(getOption("test_drake_option_12345"), "unset")
   config <- dbug()
-  if (R.utils::isPackageLoaded("abind")){
-    # Suppress goodpractice::gp(): legitimate need for detach(). # nolint
-    eval(parse(text = "detach('package:abind', unload = TRUE)"))
-  }
-  if (R.utils::isPackageLoaded("MASS")){
-    # Suppress goodpractice::gp(): legitimate need for detach(). # nolint
-    suppressWarnings(
-      eval(parse(text = "detach('package:MASS', unload = TRUE)")))
-  }
+  try(detach("package:abind", unload = TRUE), silent = TRUE) # nolint
   expect_error(abind(1))
-  expect_error(deparse(body(lda)))
 
   # Load packages with the 'packages' argument
-  config$packages <- c("abind", "MASS")
+  config$packages <- "abind"
   config$prework <- "options(test_drake_option_12345 = 'set')"
   config$plan <- drake_plan(
     x = getOption("test_drake_option_12345"),
-    y = c(deparse(body(abind)), deparse(body(lda)), x),
+    y = c(deparse(body(abind)), x),
     strings_in_dots = "literals"
   )
   config$targets <- config$plan$target
@@ -196,19 +186,9 @@ test_with_dir("packages are loaded in prework", {
   # load packages the usual way
   options(test_drake_option_12345 = "unset")
   expect_equal(getOption("test_drake_option_12345"), "unset")
-  if (R.utils::isPackageLoaded("abind")){
-    # Suppress goodpractice::gp(): legitimate need for detach()
-    eval(parse(text = "detach('package:abind', unload = TRUE)"))
-  }
-  if (R.utils::isPackageLoaded("MASS")){
-    # Suppress goodpractice::gp(): legitimate need for detach()
-    suppressWarnings(
-      eval(parse(text = "detach('package:MASS', unload = TRUE)")))
-  }
+  try(detach("package:abind", unload = TRUE), silent = TRUE) # nolint
   expect_error(abind(1))
-  expect_error(deparse(body(lda)))
-  library(abind)
-  library(MASS)
+  library(abind) # nolint
   config$packages <- NULL
   expect_false(any(c("x", "y") %in% config$cache$list()))
 
