@@ -5,7 +5,7 @@ test_with_dir("no overt errors lazy load for the debug example", {
   config <- dbug()
   config$verbose <- FALSE
   config$lazy_load <- TRUE
-  if ("parLapply" %in% tail(config$parallelism, 1)){
+  if ("parLapply" %in% tail(config$parallelism, 1)) {
     config$jobs <- 1
   }
   expect_equal(sort(outdated(config)), sort(config$plan$target))
@@ -38,8 +38,8 @@ test_with_dir("lazy loading is actually lazy", {
   lazily_loaded <- c("nextone", "yourinput")
   eagerly_loaded <- "combined"
   config <- dbug()
-  unload_these <- c(lazily_loaded, eagerly_loaded) %>%
-    intersect(y = ls(envir = config$envir))
+  unload_these <- c(lazily_loaded, eagerly_loaded)
+  unload_these <- intersect(unload_these, ls(envir = config$envir))
   remove(list = unload_these, envir = config$envir)
   config <- drake_config(
     lazy_load = TRUE,
@@ -58,13 +58,14 @@ test_with_dir("lazy loading is actually lazy", {
 
 test_with_dir("active bindings", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
+  skip_if_not_installed("bindr")
   config <- dbug()
-  if (identical(globalenv(), config$envir)){
+  if (identical(globalenv(), config$envir)) {
     skip("Testing active bindings on a global environment mangles other tests.") # nolint
   }
   testrun(config)
 
-  if ("final" %in% ls(config$envir)){
+  if ("final" %in% ls(config$envir)) {
     rm(final, envir = config$envir)
   }
   expect_false("final" %in% ls(config$envir))
